@@ -15,8 +15,13 @@ class CardToken(MuviBase):
         data = {
             'card_id': card['id']
         }
-        card_token_response = self.sdk.card_token().create(data)
-
+        try:
+            card_token_response = self.sdk.card_token().create(data)
+        except:
+            return self.error(
+                response='error_cant_create_token',
+                status=400
+            )
         if card_token_response['status'] > 299:
             return self.error(response=card_token_response['response'], status=card_token_response['status'])
 
